#
# spec file for package pgsql-ogr-fdw
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pg_name  postgresql13%{nil}
%define         ext_name pgsql-ogr-fdw
%{pg_version_from_name}

Name:           %{pg_name}-%{ext_name}
Version:        1.1.4
Release:        4.3
Summary:        PostgreSQL OGR Foreign Data Wrapper
License:        MIT
Group:          Productivity/Databases/Tools
URL:            https://github.com/pramsey/pgsql-ogr-fdw
Source0:        https://codeload.github.com/pramsey/pgsql-ogr-fdw/tar.gz/v%{version}#/%{ext_name}-%{version}.tar.gz
BuildRequires:  %{pg_name}-llvmjit-devel
BuildRequires:  %{pg_name}-server-devel
BuildRequires:  gcc-c++
BuildRequires:  gdal-devel
BuildRequires:  pkgconfig
%pg_server_requires
%if "%{pg_name}" == ""
Name:           %{ext_name}
ExclusiveArch:  do_not_build
%endif

%description
OGR is the vector half of the GDAL spatial data access library.
It allows access to a large number of GIS data formats using a simple C API for data reading and writing.
Since OGR exposes a simple table structure and PostgreSQL foreign data wrappers allow access to table structures, the fit seems pretty perfect.

%prep
%setup -q -n %{ext_name}-%{version}

%build
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
export CFLAGS="%{optflags} -fPIE -pie"
export CXXFLAGS="%{optflags} -fPIE -pie"
export PATH="$PATH:%{pg_config_bindir}"
make V=1 USE_PGXS=1 %{?_smp_mflags}

%install
export PATH="$PATH:%{pg_config_bindir}"
# Needed upstream think it is present
mkdir -p %{buildroot}/%{pg_config_bindir}
make V=1 USE_PGXS=1 install DESTDIR=%{buildroot}

%post
%{_datadir}/postgresql/install-alternatives %pg_version

%postun
%{_datadir}/postgresql/install-alternatives %pg_version

%files
%defattr(-, root, root)
%license LICENSE.md
%doc README.md FAQ.md
%{pg_config_bindir}/ogr_fdw_info
%{pg_config_pkglibdir}/ogr_fdw.so
%if %{postgresql_has_llvm}
%{pg_config_pkglibdir}/bitcode/*
%endif
%dir %{pg_config_sharedir}/extension/
%{pg_config_sharedir}/extension/ogr_fdw--1.0--1.1.sql
%{pg_config_sharedir}/extension/ogr_fdw--1.1.sql
%{pg_config_sharedir}/extension/ogr_fdw.control

%changelog
* Mon Sep 16 2024 Marcus Rueckert <mrueckert@suse.de>
- disable pg11
- enable pg16
* Sat Sep 30 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Remove problematic dependencies on clang-devel and llvm-devel:
  this will use the distribution default version, not the version
  required by postgresql*-llvmjit. Also the *-devel packages are
  not needed, only the compiler. In fact postgresql*-llvmjit-devel
  already requires the correct version of clang/llvm, so we can
  just rely on that and not bother adding our own dependencies.
* Mon Aug 14 2023 Andreas Schwab <schwab@suse.de>
- Package bitcode only when it exists
* Tue Aug  8 2023 Dirk Stoecker <opensuse@dstoecker.de>
- update to 1.1.4, refresh spec file to newer build approach
- Update to version 1.1.4
  + Support for PostgreSQL 16
  1.1.3:
  + Support PgSQL 15 regression testing changes.
  1.1.2:
  + Fixes for PgSQL 14 support of UPDATE/DELETE modes
  + More logging information available when debugging levels enabled
  1.1.1:
  + Support PostgreSQL 14
* Wed Apr 19 2023 Reinhard Max <max@suse.com>
- PostgreSQL 10 and older are EOL.
* Sun Sep 26 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Fix build by Add BuildRequirements for llvm and clang
  due to postgresql packaging changes.
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build postgresql95 and postgresql96 flavors on Tumbleweed.
* Mon May 17 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.1.0
  + New options for handling multi-sheet worksheets
  + Better handling of character encoding for sources with non-UTF8 data
  + Functions to display version info and list available drivers
- Packaging
  + fix build for pg13
  + Use llvmjit for all Leap and pg11+
  + rename %%pgversion macro to %%pg_flavor
* Mon May 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.16: bare words are no longer supported.
* Fri Jun 26 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 1.0.12
  + Add support of PostgreSQL 13
- Packaging
  + adjust _multibuild to current target 95 to 12
  + rework build and not build suse version
  + add llvmjit split and support
  + spec-cleaner
  + use common vars named and packaging way of pg at openSUSE
* Fri Sep 14 2018 Dirk Stoecker <opensuse@dstoecker.de>
- update to 1.0.6: Minor changes in support of PostgreSQL 11 release
* Thu Jun 14 2018 guillaume.gardet@opensuse.org
- Make use of multibuild to handle multiple version of postgresql
* Tue May 29 2018 guillaume.gardet@opensuse.org
- Inital version 1.0.5
